@@ -543,7 +543,10 @@ class IPN(models.Model):
             self.price_group.add
 
     def __unicode__(self):
-        return u'{0} - IPN: {1}'.format(self.name, self.code)
+        return u'IPN: {0} - {1}'.format(self.code, self.name)
+
+    class Meta:
+        ordering = ('code', )
 
 
 class PriceGroup(models.Model):
